@@ -14,15 +14,6 @@ class bcolors:
     ENDC = '\033[0m'
     BOLD = '\033[1m'
     UNDERLINE = '\033[4m'
-
-# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
-def accountverifier():
-    result = boto3.client('sts').get_caller_identity().get('Account')
-    if result == "713287746880":
-        print(bcolors.FAIL + "You are running in a wrong account, please configure your account by running 'aws configure'"  + bcolors.ENDC)
-        sys.exit(1)
-
-    # print(bcolors.OKGREEN + "Account is verified %s " % result + bcolors.ENDC)
 def taskchecker():
     REGION="us-east-1"
     DBNAME="django"
